/**
 * @file configuration.h
 * @author Bartek Kryza
 * @copyright (C) 2019 ACK CYFRONET AGH
 * @copyright This software is released under the MIT license cited in
 * 'LICENSE.txt'
 */

#include "auth/authManager.h"
#include "communication/communicator.h"
#include "messages/clientHandshakeRequest.h"
#include "messages/configuration.h"

namespace one {
namespace client {

std::string generateSessionId();

std::shared_ptr<communication::Communicator> handshake(
    const std::string &sessionId,
    std::shared_ptr<auth::AuthManager> authManager,
    std::shared_ptr<Context> context,
    messages::handshake::ClientType clientType);

std::shared_ptr<auth::AuthManager> getCLIAuthManager(
    std::shared_ptr<Context> context);

std::shared_ptr<auth::AuthManager> getOptionsAuthManager(
    std::shared_ptr<Context> context);

std::shared_ptr<auth::AuthManager> getTokenAuthManager(
    std::shared_ptr<Context> context, const folly::fbstring &token);

std::shared_ptr<messages::Configuration> getConfiguration(
    const std::string &sessionId,
    std::shared_ptr<auth::AuthManager> authManager,
    std::shared_ptr<Context> context,
    messages::handshake::ClientType clientType, bool quiet = false);

std::shared_ptr<communication::Communicator> getCommunicator(
    const std::string &sessionId,
    std::shared_ptr<auth::AuthManager> authManager,
    std::shared_ptr<Context> context,
    messages::handshake::ClientType clientType);
} // namespace client
} // namespace one
